<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Ndërmjetës Aplikacioni</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Lloj Ndërmjetësi</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adresë IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Portë</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Emër përdoruesi</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opsionale</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Fjalëkalim</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Pas formësimit, i vini shenjë “Përdor ndërmjetës” te menuja e kontekstit të aplikacionit te Nisësi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Ruaje</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adresë IP e pavlefshme</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Portë e pavlefshme</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Shkëputu</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Fshije</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Ruaje</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Po bëhet lidhja</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Shkëputu</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Jeni i sigurt se doni të fshihet ky formësim?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Lidhje Me Fill %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Lidhje Pa Fill %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>Lidhje PPPoE %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>VPN e re</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Lloj VPN-je</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Eksportoje</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Rrjet</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Ndërmjetës Aplikacioni</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Hotspot Personal</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Hollësi Rrjeti</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Ndërmjetës Sistemi</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rrjet Me Fill</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rrjet Pa Fill</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Mënyra Aeroplan</translation>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Përshtatës Rrjeti Me Fill</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Shtoni Lidhje Rrjeti</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Përshtatës Rrjeti Pa Fill</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Lidhu në rrjet të fshehtë</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Krijoni Lidhje PPPoE</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>Gjendje VPN-je</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Krijoni VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importo VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Lloj Ndërmjetësi</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL Formësimi</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adresë IP</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>Portë</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>Emër përdoruesi</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>Fjalëkalim</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Krijoni Hotspot</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>Ndërfaqe</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>Bandë</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Kanal</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Parësore</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>NetMask-ë</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Parashtesë</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>Shpejtësi</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Mënyra Aeroplan</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>Aktivizimi i mënyrës aeroplan çaktivizon rrjetin pa fill, hotspot-in personal dhe Bluetooth-in</translation>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Adresë DNS e pavlefshme</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Adresë Mac Pajisjeje</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Adresë Mac e Klonuar</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Përshtatni MTU-në</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Të përgjithshme</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Emër</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Të përgjithshme</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>Emri ekziston tashmë</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Emër</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Vetëlidhu</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Shtoni Rregullime</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Krijoni Hotspot</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>Adresë IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Kanal</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Adresë IP e përsëdytur</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adresë IP e pavlefshme</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Netmaskë-ë e pavlefshme</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Lejohet vetëm një kanal</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Kanal i pavlefshëm</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask-ë</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Adresë IP e përsëdytur</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adresë IP e pavlefshme</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Lejohet vetëm një kanal</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Kanal i pavlefshëm</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefiks</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Dorazi</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Shpërfille</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adresë IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Aplikuar vetëm në burime përkatëse</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Metodë</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>NetMask-ë</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Parashtesë</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adresë IP e pavlefshme</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Netmask-ë e pavlefshme</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Kanal i pavlefshëm</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rrjet</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Përplasje IP-sh</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Metodë</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Dorazi</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Shpërfille</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Hollësi Rrjeti</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Ndërmjetës Sistemi</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Ndërmjetës Aplikacioni</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Mënyra Aeroplan</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Hollësi Rrjeti</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rrjet</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Përplasje IP-sh</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>I çaktivizuar</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Dorazi</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Formësoje përmes Përgjegjës Rrjeti</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Hotspot Personal</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Emër përdoruesi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Shërbim</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Fjalëkalim</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Hidh tej Mirëfilltësim EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Hidh tej Mirëfilltësim PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Hidh tej Mirëfilltësim CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Hidh tej Mirëfilltësim MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Hidh tej Mirëfilltësim MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Pa Ngjeshje BSD të Dhënash</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Përdor Ngjeshje të Dhënash LZO</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Pa Ngjeshje Kryesh TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Pa Ngjeshje Fushe Protokolli</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Pa Ngjeshje Adrese/Kontrolli</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Dërgo Paketa Jehone PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Përdor MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Krijoni Lidhje PPPoE</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Ndërmjetës Sistemi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Ruaje</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Lloj Ndërmjetësi</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>Dorazi</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opsionale</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Portë</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation>Lypset mirëfilltësim</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Emër përdoruesi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Fjalëkalim</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>Ndërmjetës HTTP</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>Ndërmjetës HTTPS</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>Ndërmjetës FTP</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>Ndërmjetës SOCKS</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Shpërfill formësime ndërmjetësi për strehët dhe përkatësitë më sipër</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL Formësimi</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Siguri</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>TLS përmes tuneli</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>EAP i mbrojtur</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Ruaje fjalëkalimin për këtë përdorues</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Ruaj fjalëkalim për krejt përdoruesit</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Pyetmë përherë</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>I çaktivizuar</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>I paemër</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>I mirëfilltësuar</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Të dyja</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatik</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Version 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Version 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>Mirëfilltësim EAP</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identitet</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Mundësi Fjalëkalimi</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Kyç Privat</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Dëshmi AD-je</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Dëshmi Përdoruesi</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>ID anonime</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PAC file</source>
        <translation>Kartelë Pac</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Mirëfilltësim i Brendshëm</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>Version PEAP</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Fjalëkalim Privat</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Fjalëkalim</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Fjalëkalim i pavlefshëm</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Asnjë</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Siguri</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Kyç</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Fjalëkalim</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Lypset Siguri</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Fjalëkalim i pavlefshëm</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Asnjë</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Ndërmarrjeje</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Kyç i përbashkët</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Sistem i hapur</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Siguri</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Mirëfilltësim</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Kyç</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Fjalëkalim</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN e Thelluar</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Përshtatni Portë Kanali</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Portë Kanali</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Përshtatni Interval Rinegocimi</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Interval Rinegocimi</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Përdor Ngjeshje të Dhënash LZO</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Përdor Lidhje TCP</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Përdor Pajisje TAP</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Përshtatni MTU Tuneli</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Përshtatni Madhësi Fragmenti UDP</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>Madhësi Fragmenti UDP</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Strehë të Largëta Kuturu</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN e Thelluar</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (parazgjedhje)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>I sigurt (parazgjedhje)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>I dobët</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Asnjë</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T Kur Mundet (parazgjedhje)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T Përherë</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>UDP Cisco</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>I çaktivizuar</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Grupi 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Grupi 2 (parazgjedhje)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Grupi 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Shërbyes (parazgjedhje)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Grupi 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Përkatësi</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Prodhues</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Fshehtëzim</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>GRUP IKE DH</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Portë Vendore</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Çaktivizo Pikasje Ortaku të Vdekur</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Aktivizo IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Emër Grupi</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>ID Grupi</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Algoritme Phase1</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Algoritme Phase2</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Kanal i pavlefshëm</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Dëshmi AD-je</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Ndërmjetës</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Lejo Cisco Secure Desktop Trojan</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>Programth CSD</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Dëshmi Përdoruesi</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Kyç Privat</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Për Frazëkalim Kyçesh përdor FSID</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Kanal i pavlefshëm</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Dëshmi (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Fjalëkalim</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Dëshmi me Fjalëkalime (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Kyç Statik</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>U ruajt</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Pyet</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Jo e Domosdoshme</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Lloj Mirëfilltësimi</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Dëshmi AD-je</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Dëshmi Përdoruesi</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Kyç Privat</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Mundësi Fjalëkalimi</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Fjalëkalim Privat</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Emër përdoruesi</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Përshtatni Kah Kyçi</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Kah Kyçi</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>IP e largët</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>IP vendore</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Krejt të Gatshmet (parazgjedhje)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (më pak i sigurt)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (më i sigurti)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Hidh tej Mirëfilltësim EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Hidh tej Mirëfilltësim PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Hidh tej Mirëfilltësim CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Hidh tej Mirëfilltësim MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Hidh tej Mirëfilltësim MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Pa Ngjeshje BSD të Dhënash</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Përdor Ngjeshje të Dhënash LZO</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Pa Ngjeshje Kryesh TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Pa Ngjeshje Fushe Protokolli</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Pa Ngjeshje Adrese/Kontrolli</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Dërgo Paketa Jehone PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Përdor MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Siguri</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>Gjendje VPN-je</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Krijoni VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importo VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Gabim Importimi</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Gabim kartele</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>Ndërmjetës VPN</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Jo e Domosdoshme</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Lloj Ndërmjetësi</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP Shërbyesi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Portë</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Riprovo Pambarim Kur Dështohet</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Emër përdoruesi</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Fjalëkalim</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>Kartelë AD</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Shpërfill Sinjalizime Mbi Dëshminë</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>Përdor Zgjerime TLS Strehëemrash</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>Siguri VPN</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Parazgjedhje</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Asnjë</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Shifër</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>Mirëfilltësim HMAC</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Kanal i pavlefshëm</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>U ruajt</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Pyet</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Jo e Domosdoshme</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Emër përdoruesi</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Mundësi Fjalëkalimi</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Fjalëkalim</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>Përkatësi NT</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>Ndërmjetës VPN</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP Shërbyesi</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Portë</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Emër përdoruesi</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Fjalëkalim</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Kanal i pavlefshëm</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Kyç Privat</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>Agjent SSH</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Kartë e Mençur</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Dëshmi AD-je</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Lloj Mirëfilltësimi</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Dëshmi Përdoruesi</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Emër përdoruesi</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Fjalëkalim</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Kërko doemos një Adresë IP të Brendshme</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Detyro Kapsulizim UDP</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Përdor Ngjeshje IP</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Aktivizo Propozime të Përshtatura Shifre</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>Mirëfilltësim TLS VPN-je</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Parazgjedhje</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Klient</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Shërbyes</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Përputhje Subjekti</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Lloj Dëshmie të Largët</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Kartelë Kyçesh</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Përshtatni Kah Kyçi</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Kah Kyçi</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Kanal i pavlefshëm</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>U ruajt</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Pyet</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Jo e Domosdoshme</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Emër përdoruesi</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Mundësi Fjalëkalimi</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Fjalëkalim</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Emër Grupi</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Fjalëkalim Grupi</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Përdor Mirëfilltësim Hibrid</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Kartelë AD</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Së pari futni kabllon e rrjetit në vend</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Përshtatës Rrjeti Me Fill</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Shtoni Lidhje Rrjeti</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Përzgjidhni Rregullime</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Përshtatës Rrjeti Pa Fill</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Mbylle Hotspot-in</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Nëse doni të lidheni me një rrjet pa fill, së pari, çaktivizoni hotspot-in</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Lidhu në rrjet të fshehtë</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Adresë Mac Pajisjeje</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Përshtatni MTU-në</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokoll</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Lloj Sigurie</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Bandë</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Ndërfaqe</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>NetMask-ë</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Parësore</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Parashtesë</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Shpejtësi</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Pajisje e çaktivizuar</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>E lidhur, por pa hyrje Internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Jo e lidhur</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Kablloja e rrjetit është e hequr</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Po lidhet</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Po bëhet mirëfilltësim</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Po merret adresë IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>E lidhur</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>E shkëputur</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Përplasje IP-sh</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>U dështua</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Po merret adresë</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Rrjet Me Fill</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Rrjet Me Fill %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rrjet Pa Fill</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rrjet Pa Fill %1</translation>
    </message>
</context>
</TS>